@@ -2,6 +2,7 @@ import angular from 'angular';
 import { saveAs } from 'file-saver';
 import coreModule from 'app/core/core_module';
 import { DashboardModel } from '../../state';
+import { DashboardSrv } from '../../services/DashboardSrv';
 
 const template = `
 <div class="modal-body">
@@ -50,7 +51,7 @@ export class SaveProvisionedDashboardModalCtrl {
   dismiss: () => void;
 
   /** @ngInject */
-  constructor(dashboardSrv) {
+  constructor(dashboardSrv: DashboardSrv) {
     this.dashboardModel = dashboardSrv.getCurrent();
     this.dash = this.dashboardModel.getSaveModelClone();
     delete this.dash.id;
