@@ -128,7 +128,7 @@ describe('DashboardModel', () => {
     });
 
     it('dashboard schema version should be set to latest', () => {
-      expect(model.schemaVersion).toBe(20);
+      expect(model.schemaVersion).toBe(21);
     });
 
     it('graph thresholds should be migrated', () => {
@@ -139,6 +139,27 @@ describe('DashboardModel', () => {
       expect(graph.thresholds[1].value).toBe(400);
       expect(graph.thresholds[1].fillColor).toBe('red');
     });
+
+    it('graph thresholds should be migrated onto specified thresholds', () => {
+      model = new DashboardModel({
+        panels: [
+          {
+            type: 'graph',
+            y_formats: ['kbyte', 'ms'],
+            grid: {
+              threshold1: 200,
+              threshold2: 400,
+            },
+            thresholds: [{ value: 100 }],
+          },
+        ],
+      });
+      graph = model.panels[0];
+      expect(graph.thresholds.length).toBe(3);
+      expect(graph.thresholds[0].value).toBe(100);
+      expect(graph.thresholds[1].value).toBe(200);
+      expect(graph.thresholds[2].value).toBe(400);
+    });
   });
 
   describe('when migrating to the grid layout', () => {
@@ -438,7 +459,7 @@ describe('DashboardModel', () => {
     });
 
     it('should slugify dashboard name', () => {
-      expect(model.panels[0].links[3].url).toBe(`/dashboard/db/my-other-dashboard`);
+      expect(model.panels[0].links[3].url).toBe(`dashboard/db/my-other-dashboard`);
     });
   });
 
@@ -506,6 +527,51 @@ describe('DashboardModel', () => {
       });
     });
   });
+
+  describe('when migrating labels from DataFrame to Field', () => {
+    let model: any;
+    beforeEach(() => {
+      model = new DashboardModel({
+        panels: [
+          {
+            //graph panel
+            options: {
+              dataLinks: [
+                {
+                  url: 'http://mylink.com?series=${__series.labels}&${__series.labels.a}',
+                },
+              ],
+            },
+          },
+          {
+            //  panel with field options
+            options: {
+              fieldOptions: {
+                defaults: {
+                  links: [
+                    {
+                      url: 'http://mylink.com?series=${__series.labels}&${__series.labels.x}',
+                    },
+                  ],
+                },
+              },
+            },
+          },
+        ],
+      });
+    });
+
+    describe('data links', () => {
+      it('should replace __series.label variable with __field.label', () => {
+        expect(model.panels[0].options.dataLinks[0].url).toBe(
+          'http://mylink.com?series=${__field.labels}&${__field.labels.a}'
+        );
+        expect(model.panels[1].options.fieldOptions.defaults.links[0].url).toBe(
+          'http://mylink.com?series=${__field.labels}&${__field.labels.x}'
+        );
+      });
+    });
+  });
 });
 
 function createRow(options: any, panelDescriptions: any[]) {
