@@ -2,6 +2,8 @@ import _ from 'lodash';
 import { NavModelSrv } from 'app/core/core';
 import { ILocationService } from 'angular';
 import { BackendSrv } from '@grafana/runtime';
+import { GrafanaRootScope } from 'app/routes/GrafanaCtrl';
+import { CoreEvents } from 'app/types';
 
 export class SnapshotListCtrl {
   navModel: any;
@@ -9,7 +11,7 @@ export class SnapshotListCtrl {
 
   /** @ngInject */
   constructor(
-    private $rootScope: any,
+    private $rootScope: GrafanaRootScope,
     private backendSrv: BackendSrv,
     navModelSrv: NavModelSrv,
     private $location: ILocationService
@@ -35,7 +37,7 @@ export class SnapshotListCtrl {
   }
 
   removeSnapshot(snapshot: any) {
-    this.$rootScope.appEvent('confirm-modal', {
+    this.$rootScope.appEvent(CoreEvents.showConfirmModal, {
       title: 'Delete',
       text: 'Are you sure you want to delete snapshot ' + snapshot.name + '?',
       yesText: 'Delete',
