@@ -8,6 +8,7 @@ import appEvents from 'app/core/app_events';
 import locationUtil from 'app/core/utils/location_util';
 import kbn from 'app/core/utils/kbn';
 import { store } from 'app/store/store';
+import { CoreEvents } from 'app/types';
 
 export const queryParamsToPreserve: { [key: string]: boolean } = {
   kiosk: true,
@@ -86,7 +87,7 @@ export class PlaylistSrv {
     this.storeUnsub = store.subscribe(() => this.storeUpdated());
     this.validPlaylistUrl = this.$location.path();
 
-    appEvents.emit('playlist-started');
+    appEvents.emit(CoreEvents.playlistStarted);
 
     return this.backendSrv.get(`/api/playlists/${playlistId}`).then((playlist: any) => {
       return this.backendSrv.get(`/api/playlists/${playlistId}/dashboards`).then((dashboards: any) => {
@@ -101,7 +102,7 @@ export class PlaylistSrv {
     if (this.isPlaying) {
       const queryParams = this.$location.search();
       if (queryParams.kiosk) {
-        appEvents.emit('toggle-kiosk-mode', { exit: true });
+        appEvents.emit(CoreEvents.toggleKioskMode, { exit: true });
       }
     }
 
@@ -116,7 +117,7 @@ export class PlaylistSrv {
       this.$timeout.cancel(this.cancelPromise);
     }
 
-    appEvents.emit('playlist-stopped');
+    appEvents.emit(CoreEvents.playlistStopped);
   }
 }
 
