@@ -1,6 +1,7 @@
 import _ from 'lodash';
 import { QueryCtrl } from 'app/plugins/sdk';
 import { auto } from 'angular';
+import { PanelEvents } from '@grafana/data';
 
 export interface MssqlQuery {
   refId: string;
@@ -52,8 +53,8 @@ export class MssqlQueryCtrl extends QueryCtrl {
       }
     }
 
-    this.panelCtrl.events.on('data-received', this.onDataReceived.bind(this), $scope);
-    this.panelCtrl.events.on('data-error', this.onDataError.bind(this), $scope);
+    this.panelCtrl.events.on(PanelEvents.dataReceived, this.onDataReceived.bind(this), $scope);
+    this.panelCtrl.events.on(PanelEvents.dataError, this.onDataError.bind(this), $scope);
   }
 
   onDataReceived(dataList: any) {
