@@ -1,14 +1,13 @@
 import React, { FC } from 'react';
-import _ from 'lodash';
 
 import { MetricSelect } from 'app/core/components/Select/MetricSelect';
 import { TemplateSrv } from 'app/features/templating/template_srv';
-import { SelectOptionItem } from '@grafana/ui';
+import { SelectableValue } from '@grafana/data';
 
 export interface Props {
-  onChange: (perSeriesAligner) => void;
+  onChange: (perSeriesAligner: any) => void;
   templateSrv: TemplateSrv;
-  alignOptions: SelectOptionItem[];
+  alignOptions: Array<SelectableValue<string>>;
   perSeriesAligner: string;
 }
 
