@@ -1,7 +1,7 @@
 import React from 'react';
-import { PanelProps, LogRows, CustomScrollbar } from '@grafana/ui';
+import { LogRows, CustomScrollbar } from '@grafana/ui';
+import { LogsDedupStrategy, PanelProps } from '@grafana/data';
 import { Options } from './types';
-import { LogsDedupStrategy } from '@grafana/data';
 import { dataFrameToLogsModel } from 'app/core/logs_model';
 import { sortLogsResult } from 'app/core/utils/explore';
 
@@ -21,18 +21,18 @@ export const LogsPanel: React.FunctionComponent<LogsPanelProps> = ({
     );
   }
 
-  const newResults = data ? dataFrameToLogsModel(data.series, data.request.intervalMs) : null;
+  const newResults = data ? dataFrameToLogsModel(data.series, data.request.intervalMs, timeZone) : null;
   const sortedNewResults = sortLogsResult(newResults, sortOrder);
 
   return (
     <CustomScrollbar autoHide>
       <LogRows
-        data={sortedNewResults}
+        logRows={sortedNewResults.rows}
         dedupStrategy={LogsDedupStrategy.none}
         highlighterExpressions={[]}
         showTime={showTime}
-        showLabels={false}
         timeZone={timeZone}
+        allowDetails={true}
       />
     </CustomScrollbar>
   );
